@@ -8,7 +8,7 @@
 #define QT_FEATURE_build_all -1
 #define QT_FEATURE_c__11 1
 #define QT_FEATURE_c__14 1
-#define QT_FEATURE_c__1z -1
+#define QT_FEATURE_c__1z 1
 #define QT_FEATURE_c99 1
 #define QT_FEATURE_c11 1
 #define QT_FEATURE_thread 1
@@ -20,7 +20,7 @@
 #define QT_VISIBILITY_AVAILABLE true
 #define QT_FEATURE_separate_debug_info -1
 #define QT_FEATURE_static -1
-#define QT_VERSION_STR "5.12.0"
+#define QT_VERSION_STR "5.12.4"
 #define QT_VERSION_MAJOR 5
 #define QT_VERSION_MINOR 12
-#define QT_VERSION_PATCH 0
+#define QT_VERSION_PATCH 4
